Cacao
===============
small validator and serializer for your needs. To start using that please follow the instructions bellow.

Installing
============

.. code-block:: bash

    pip install ...

Usage
=====

.. code-block:: bash

    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'